@@ -1,5 +1,5 @@
 package Git::Raw::Note;
-$Git::Raw::Note::VERSION = '0.72';
+$Git::Raw::Note::VERSION = '0.73';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Git::Raw::Note - Git note class
 
 =head1 VERSION
 
-version 0.72
+version 0.73
 
 =head1 DESCRIPTION
 
@@ -39,7 +39,7 @@ Remove the note from C<$commitish>.
 
 =head2 id( )
 
-Retrieve the note's id.
+Retrieve the note's id as a string.
 
 =head2 message( )
 
