@@ -1,5 +1,5 @@
 package Git::Raw::Object;
-$Git::Raw::Object::VERSION = '0.72';
+$Git::Raw::Object::VERSION = '0.73';
 use strict;
 use warnings;
 use Carp;
@@ -29,7 +29,7 @@ Git::Raw::Object - Git object
 
 =head1 VERSION
 
-version 0.72
+version 0.73
 
 =head1 DESCRIPTION
 
@@ -38,6 +38,20 @@ L<Git::Raw::Object> provides a namespace for object constants.
 B<WARNING>: The API of this module is unstable and may change without warning
 (any change will be appropriately documented in the changelog).
 
+=head1 METHODS
+
+=head2 id( )
+
+Retrieve the id of the object, as a string.
+
+=head2 lookup( $id )
+
+Retrieve the object corresponding to C<$id>. Returns a L<Git::Raw::Object>.
+
+=head2 type( )
+
+Get the object type.
+
 =head1 CONSTANTS
 
 =head2 ANY
