@@ -1,5 +1,5 @@
 package Git::Raw::Odb;
-$Git::Raw::Odb::VERSION = '0.72';
+$Git::Raw::Odb::VERSION = '0.73';
 use strict;
 use warnings;
 
@@ -12,7 +12,7 @@ Git::Raw::Odb - Git object database class
 
 =head1 VERSION
 
-version 0.72
+version 0.73
 
 =head1 DESCRIPTION
 
@@ -43,6 +43,12 @@ have changed on disk while the library is running, this function will force a
 reload of the underlying indexes. Use this method when you're confident that an
 external application has tampered with the ODB.
 
+=head2 foreach( $repo, $callback )
+
+Run C<$callback> for every object available in the database. The callback receives
+a single argument, the OID of the object. A non-zero return value will terminate
+the loop.
+
 =head2 add_backend( $backend, $priority )
 
 Add a custom backend to the ODB. The backends are checked in relative ordering,
@@ -54,6 +60,11 @@ Add an alternate custom backend to the ODB. Alternate backends are always
 checked for objects after all the main backends have been exhausted. Writing is
 disabled on alternate backends.
 
+=head2 read( $id )
+
+Read an object from the database. Returns a L<Git::Raw::Odb::Object> or C<undef>
+if the object does not exist.
+
 =head1 AUTHOR
 
 Jacques Germishuys <jacquesg@striata.com>
